/**
  * This file is part of Organiser Feed.
  *
  * Organiser Feed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Organiser Feed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Organiser Feed.  If not, see <http://www.gnu.org/licenses/>.
  *
  */

import QtQuick 1.1

import com.nokia.meego 1.0
import "UIConstants.js" as UIConstants
import organiserfeed 1.0

Page {
    tools: ToolBarLayout {
        id: subPageToolbar
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: pageStack.pop()
        }
    }
    orientationLock: PageOrientation.LockPortrait


    ListView {
        anchors.fill: parent

        header: Column {
            width: parent.width
            HeaderItem {
                text: qsTrId("qtn_calendar_settings")
            }

            RulerItem { id: ruler }
        }

        model: CalendarListModel {}
        delegate: Rectangle {
            id: listItem
            height: UIConstants.LIST_ITEM_HEIGHT_DEFAULT
            width: parent.width
            color: "#00ffffff"

            MouseArea {
                id: mouseArea
                anchors.fill: parent
                anchors.margins: UIConstants.DEFAULT_MARGIN

                Row {
                    anchors { top: parent.top; bottom: parent.bottom; }
                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        text: name
                        font.bold: true
                        width: parent.parent.width - drilldownImage.width - 2 * parent.anchors.leftMargin
                    }

                    Image {
                        id: drilldownImage
                        width: sourceSize.width
                        source: "image://theme/icon-m-common-drilldown-arrow-inverse"
                        anchors.verticalCenter: parent.verticalCenter
                    }
                }

                onClicked: {
                    pageStack.push(Qt.resolvedUrl("CalendarSettingsPage.qml"), { 'calendarName': name, 'uid': uid })
                }
            }

            states: [
                State {
                    when: mouseArea.pressed
                    PropertyChanges { target: listItem; color: "#40ffffff" }
                }

            ]
        }
    }

}
