/**
  * This file is part of Organiser Feed.
  *
  * Organiser Feed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Organiser Feed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Organiser Feed.  If not, see <http://www.gnu.org/licenses/>.
  *
  */

import QtQuick 1.1
import com.nokia.meego 1.0
import "UIConstants.js" as UIConstants

Rectangle {
    id: comboBoxItem

    property string label
    property string value
    property bool enabled: true

    signal show()

    width: parent.width
    height: UIConstants.LIST_ITEM_HEIGHT_DEFAULT
    color: "#00ffffff"

    MouseArea {
        id: mouseArea
        anchors.fill: parent

        onClicked: { if (comboBoxItem.enabled) comboBoxItem.show() }

        Row {
            anchors.fill: parent
            anchors.leftMargin: UIConstants.DEFAULT_MARGIN
            anchors.rightMargin: anchors.leftMargin

            Column {
                width: comboBoxItem.width - selectedImage.width - 2 * parent.anchors.leftMargin
                anchors.verticalCenter: parent.verticalCenter
                spacing: 2
                enabled: comboBoxItem.enabled

                CustomLabel {
                    id: label
                    text: comboBoxItem.label
                    font.bold: true
                    enabled: comboBoxItem.enabled
                }

                CustomLabel {
                    id: value
                    text: comboBoxItem.value
                    enabled: comboBoxItem.enabled
                    style: LabelStyle {
                        fontPixelSize: UIConstants.FONT_SMALL
                        textColor: UIConstants.COLOR_INVERTED_SECONDARY_FOREGROUND
                    }
                }
            }


            Image {
                id: selectedImage
                width: sourceSize.width
                source: theme.inverted ? "image://theme/icon-m-textinput-combobox-arrow" : "image://theme/icon-m-common-combobox-arrow-selected"
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    states: [
        State {
            name: "clicked"
            when: comboBoxItem.enabled && mouseArea.pressed
            PropertyChanges { target: comboBoxItem; color: "#40ffffff" }
        }

    ]
}
