/**
  * This file is part of Organiser Feed.
  *
  * Organiser Feed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Organiser Feed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Organiser Feed.  If not, see <http://www.gnu.org/licenses/>.
  *
  */

import QtQuick 1.1

import com.nokia.meego 1.0
import "UIConstants.js" as UIConstants
import organiserfeed 1.0

Page {
    Settings {
        id: settings
    }

    id: root

    anchors.fill: parent
    tools: ToolBarLayout {
        id: subPageToolbar
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: pageStack.pop()
        }
    }
    orientationLock: PageOrientation.LockPortrait

    SelectionDialog {
        id: aggregationModeDialog
        titleText: qsTrId("qtn_aggregation_mode_dialog_title")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            model.append({ name: qsTrId("qtn_no_aggregation_mode"), value: Settings.NoAggregationMode })
            model.append({ name: qsTrId("qtn_one_per_day_aggregation_mode"), value: Settings.AggregatedMode, aggregationPeriod: 24 * 60 * 60 })
            model.append({ name: qsTrId("qtn_all_in_one_aggregation_mode"), value: Settings.AggregatedMode, aggregationPeriod: 0 })
            model.append({ name: qsTrId("qtn_category_aggregation_mode"), value: Settings.CategoryMode })
        }
    }

    Flickable {
        anchors.fill: parent
        flickableDirection: Flickable.VerticalFlick
        contentWidth: width
        contentHeight: content.height

        Column {
            id: content
            width: parent.parent.width

            HeaderItem {
                text: qsTrId("qtn_display_settings")
            }

            RulerItem {}

            SwitchItem {
                label: qsTrId("qtn_nearest_events_on_top")
                checked: settings.nearestFirst
                onCheckedChanged: settings.nearestFirst = checked
                visible: settings.aggregationMode == Settings.NoAggregationMode
                         || settings.aggregationMode == Settings.OnePerDayAggregationMode
                         || settings.aggregationMode == Settings.AggregatedMode
            }

            SwitchItem {
                label: qsTrId("qtn_icon_mode")
                checked: settings.iconMode == Settings.DayIcon
                onCheckedChanged: settings.iconMode = (checked ? Settings.DayIcon : Settings.PlainIcon)
                visible: settings.aggregationMode == Settings.NoAggregationMode
            }

            SwitchItem {
                label: qsTrId("qtn_grayscale_icons")
                checked: settings.grayscaleIcons
                onCheckedChanged: settings.grayscaleIcons = checked
                visible: (settings.iconMode == Settings.DayIcon && settings.aggregationMode == Settings.NoAggregationMode)
                         || settings.aggregationMode == Settings.OnePerDayAggregationMode
                         || settings.aggregationMode == Settings.AggregatedMode
            }

            SwitchItem {
                label: qsTrId("qtn_aggregate_todos")
                checked: settings.aggregateTodos
                onCheckedChanged: settings.aggregateTodos = checked
                visible: settings.aggregationMode == Settings.OnePerDayAggregationMode
                         || settings.aggregationMode == Settings.AggregatedMode
            }

            ComboBoxItem {
                label: qsTrId("qtn_aggregation_mode")
                value: {
                    switch(settings.aggregationMode) {
                    case Settings.NoAggregationMode:
                        return qsTrId("qtn_no_aggregation_mode");
                    case Settings.AggregatedMode:
                        if (settings.aggregationPeriod === 24 * 60 * 60)
                            return qsTrId("qtn_one_per_day_aggregation_mode");
                        else
                            return qsTrId("qtn_all_in_one_aggregation_mode");
                    case Settings.CategoryMode:
                        return qsTrId("qtn_category_aggregation_mode");
                    }
                }
                onShow: {
                    var dialog = aggregationModeDialog
                    dialog.open()
                    // Set the selected index after opening the dialog - otherwise
                    // the model items are not drawn until the screen is touched
                    for (var i = 0; i < dialog.model.count; i++) {
                        if (dialog.model.get(i).value === settings.aggregationMode
                                && (settings.aggregationMode !== Settings.AggregatedMode
                                    || settings.aggregationPeriod === dialog.model.get(i).aggregationPeriod )) {
                            dialog.selectedIndex = i;
                            break;
                        }
                    }
                }

                Connections {
                    target: aggregationModeDialog
                    onSelectedIndexChanged: {
                        var entry = aggregationModeDialog.model.get(aggregationModeDialog.selectedIndex);
                        settings.aggregationMode = entry.value
                        if (entry.value === Settings.AggregatedMode) {
                            settings.aggregationPeriod = entry.aggregationPeriod
                        }
                    }
                }
            }

        }
    }


}
