/**
  * This file is part of Organiser Feed.
  *
  * Organiser Feed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Organiser Feed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Organiser Feed.  If not, see <http://www.gnu.org/licenses/>.
  *
  */

import QtQuick 1.1
import com.nokia.meego 1.0
import "UIConstants.js" as UIConstants
import organiserfeed 1.0

Page {
    tools: commonTools
    anchors.fill: parent
    orientationLock: PageOrientation.LockPortrait

    Settings {
        id: settings
    }

    SelectionDialog {
        id: expiryModeDialog
        titleText: qsTrId("qtn_expiry_mode")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            model.append({ name: qsTrId("qtn_expiry_mode_start"), value: Settings.OnEventStart })
            model.append({ name: qsTrId("qtn_expiry_mode_end"), value: Settings.OnEventEnd })
        }
    }


    SelectionDialog {
        id: totalMaximumEntriesDialog
        titleText: qsTrId("qtn_maximum_total_entries_dialog_title")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            model.append({ name: "1", value: 1 })
            model.append({ name: "2", value: 2 })
            model.append({ name: "3", value: 3 })
            model.append({ name: "5", value: 5 })
            model.append({ name: "10", value: 10 })
            model.append({ name: qsTrId("qtn_unlimited"), value: 0xffff })
        }
    }

    Flickable {
        anchors.fill: parent
        flickableDirection: Flickable.VerticalFlick
        contentWidth: width
        contentHeight: content.height

        Column {
            id: content
            width: parent.parent.width

            HeaderItem {
                text: qsTrId("qtn_application_name")
            }

            RulerItem {}

            Label {
                anchors { left: parent.left; right: parent.right }
                anchors.leftMargin: 8
                anchors.rightMargin: anchors.leftMargin
                height: paintedHeight + 24

                verticalAlignment: Text.AlignVCenter

                text: qsTrId("qtn_application_description")
            }

            RulerItem {}

            SwitchItem {
                label: qsTrId("qtn_enable_event_feeds")
                checked: settings.enabled
                onCheckedChanged: settings.enabled = checked
            }

            ComboBoxItem {
                label: qsTrId("qtn_expiry_mode")

                value: settings.expiryMode == Settings.OnEventStart ? qsTrId("qtn_expiry_mode_start") : qsTrId("qtn_expiry_mode_end")

                onShow: {
                    expiryModeDialog.open()

                    // Set the selected index after opening the dialog - otherwise
                    // the model items are not drawn until the screen is touched
                    for (var i = 0; i < expiryModeDialog.model.count; i++) {
                        if (expiryModeDialog.model.get(i).value == settings.expiryMode) {
                            expiryModeDialog.selectedIndex = i;
                            break;
                        }
                    }
                }

                Connections {
                    target: expiryModeDialog
                    onSelectedIndexChanged: {
                        settings.expiryMode = expiryModeDialog.model.get(expiryModeDialog.selectedIndex).value
                    }
                }
            }

            ComboBoxItem {
                label: qsTrId("qtn_maximum_total_entries")
                value: settings.maxEntries === 0xffff ? qsTrId("qtn_unlimited") : settings.maxEntries
                visible: (settings.aggregationMode === Settings.AggregatedMode && settings.aggregationPeriod !== 0)
                         || settings.aggregationMode === Settings.NoAggregationMode
                onShow: {
                    var dialog = totalMaximumEntriesDialog
                    dialog.open()
                    // Set the selected index after opening the dialog - otherwise
                    // the model items are not drawn until the screen is touched
                    for (var i = 0; i < dialog.model.count; i++) {
                        if (dialog.model.get(i).value === settings.maxEntries) {
                            dialog.selectedIndex = i;
                            break;
                        }
                    }
                }

                Connections {
                    target: totalMaximumEntriesDialog
                    onSelectedIndexChanged: {
                        settings.maxEntries = totalMaximumEntriesDialog.model.get(totalMaximumEntriesDialog.selectedIndex).value
                    }
                }
            }


            DrilldownItem {
                label: qsTrId("qtn_display_settings")
                onShow: {
                    pageStack.push(Qt.resolvedUrl("DisplaySettingsPage.qml"))
                }
            }

            DrilldownItem {
                label: qsTrId("qtn_calendar_settings")
                onShow: {
                    pageStack.push(Qt.resolvedUrl("CalendarListPage.qml"))
                }
            }

        }
    }


}
